.. -*- mode: rst -*-

Implementation Notes
====================

Where possible, the implementation has been revised several times using profiling techniques in order to create the best performing simulation. In this section we describe in detail some of the choices we've made, and the impact that these choices have had on the performance of the overall simulation.

.. toctree::
   :maxdepth: 1

   neighborhoods
